You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@airflow.apache.org by GitBox <gi...@apache.org> on 2022/05/19 16:45:09 UTC

[GitHub] [airflow] pingzh commented on pull request #21877: AIP-45 Remove dag parsing in airflow run local

pingzh commented on PR #21877:
URL: https://github.com/apache/airflow/pull/21877#issuecomment-1131948812

   > What kind of performance difference does this make on 2.2.x btw? (Just curious, it still feels like the right thing to do)
   
   @ashb I am still in the process of porting over this change to 2.2.4. 
   
   Based on our current production based on 1.10.4, it helped to bring down average task start time from 24 seconds to 3 seconds (across all three airflow clusters) and reduce peak memory usage by around 45%. (some context here, all of our dags have `run_as_user` for security, thus the `fork` in StandardTaskRunner won't help).


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: commits-unsubscribe@airflow.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org